/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2003 NextApp, Inc.
 *
 * Echo is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Echo is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Echo; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/**
 * Applys the specified style's background and foreground colors to the
 * specified element.
 */
function E_applyStyle(E_element, E_style) {
    E_element.style.color = E_style.color;
    E_element.style.backgroundColor = E_style.backgroundColor;
    E_element.style.fontFamily = E_style.fontFamily;
    E_element.style.fontSize = E_style.fontSize;
    E_element.style.fontStyle = E_style.fontStyle;
    E_element.style.fontWeight = E_style.fontWeight;
    E_element.style.textDecoration = E_style.textDecoration;
}

function E_applyStyleGroup(E_groupName, E_style) {
    if (document.getElementById) {
        var E_i = 0;
        var E_element;

        do {
            E_element = document.getElementById(E_groupName + "_" + E_i);
            if (E_element) {
                E_applyStyle(E_element, E_style);
            }
            ++E_i;
        } while (E_element);
    }
}

/**
 * Returns the style object with the specified name.
 */
function E_getStyle(E_styleName) {
    var E_style = null;
    var E_i = 0;
    var E_rules;
    var E_length;
    var E_testName = E_styleName.toLowerCase();
    var E_name;
    var E_dotIndex;
    
    if (document.styleSheets && document.styleSheets[0]) {
        if (document.styleSheets[0].cssRules) {
            E_rules = document.styleSheets[0].cssRules;
        } else if (document.styleSheets[0].rules) {
            E_rules = document.styleSheets[0].rules;
        }
    }

    if (E_rules) {
        E_length = E_rules.length;

        while (E_i < E_length && E_style == null) {
            E_name = E_rules[E_i].selectorText.toLowerCase();
            E_dotIndex = E_name.indexOf(".");
            if (E_dotIndex >= 0) {
                E_name = E_name.substring(E_dotIndex + 1);
            }
            if (E_name == E_testName) {
                E_style = E_rules[E_i].style;
            }
            ++E_i;
        }
    }

    return E_style;
}
