/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2003 NextApp, Inc.
 *
 * Echo is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Echo is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Echo; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/** Indicates this frame has been initialized */
var E_initialized = false;

/**
 * Frame initialization event.
 * This script causes the E_initializeTasks() methods to be called in all 
 * browser frames, in a bottom-up order (the inverse of the top-down order
 * that onLoad() methods are called).  Frames are guaranteed that their 
 * parent frames E_initializeTasks() method has been executed before their own.
 */
function E_initialize() {

    if (window.E_rootFrame) {
        // Frame IS top frame.
        E_initialized = true;
    } else {
        // Frame is NOT top frame.
        if (parent.E_initialized) {
            E_initialized = true;
        }
    }

    if (E_initialized) {
        // Frame is top frame or parent frame has been initialized.
        if (this.E_initializeTasks) {
            // Call initializeTasks for this frame if it has not been done yet.
            E_initializeTasks();
        }

        for (var E_i = 0; E_i < frames.length; ++E_i) {
        
            // Safely determine if each child frame has initialization tasks.
            // This must be done with SafeInvoke because the frame might be
            // foreign (for example, if it's an HttpPane), in which case
            // the browser will throw an exception to maintain cross-site
            // scripting security.
            if (E_try(null, "E_hasInitializer", frames[E_i])) {
                if (! frames[E_i].E_initialized) {
                    frames[E_i].E_initialize();
                }
            }
        }
    }
}

/**
 * Returns true if the given frame has an initializeTasks() method.
 * This is done as a separate method so that it may called with
 * SafeInvoke.
 */
function E_hasInitializer(E_frame) {
    return E_frame.E_initialize;
}
