/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2003 NextApp, Inc.
 *
 * Echo is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Echo is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Echo; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/**
 * Called when a check box is clicked.
 *
 * E_id: The ID of the checkbox clicked
 * E_originalState: The state of the checkbox when the page was originally rendered.
 * E_notify: True if the server should be notified immediately of state changes (via control frame submit)
 * E_defaultImageUri: The URI of the state image displayed when the check box is not selected (unchecked).
 * E_selectedImageUri: The URI of the state image displayed when the check box is selected (checked).
 */
function E_checkBoxAction(E_id, E_originalState, E_notify, E_defaultImageUri, E_selectedImageUri) {
    // Get state and invert
    var E_state;
    var E_parameterValue = E_getParameter(E_id);
    
    if (E_parameterValue != null && E_parameterValue.indexOf("1") != -1) {
        E_state = false;
    } else if (E_parameterValue != null && E_parameterValue.indexOf("0") != -1) {
        E_state = true;
    } else {
        E_state = !E_originalState;
    }

    // Store new selection data in control form
    E_setParameter(E_id, E_state ? "1" : "0");

    // Update checkbox icon.
    document.images["E_TBIMG_" + E_id].src = (E_state ? E_selectedImageUri : E_defaultImageUri);

    // Notify server of change if necessary
    if (E_notify) {
        E_setAction(E_id, "press");
    }
}

/**
 * Called when a radio button is clicked.
 *
 * E_id: The ID of the radio button clicked
 * E_groupId: The radio button's group ID.  The selected value will be stored in the parameter for this ID.
 * E_originalSelectedId: The ID of the selected radio button when the page was originally rendered.
 * E_notify: True if the server should be notified immediately of state changes (via control frame submit)
 * E_defaultImageUri: The URI of the state image displayed when the radio button is not selected (unchecked).
 * E_selectedImageUri: The URI of the state image displayed when the radio button is selected (checked).
 */
function E_radioButtonAction(E_id, E_groupId, E_originalSelectedId, E_notify, E_defaultImageUri, E_selectedImageUri) {
    // Determine previously selected id.
    var E_selectedId;
    var E_parameterValue = E_getParameter(E_groupId);
    if (E_parameterValue != null && E_parameterValue.length > 0 && E_parameterValue.charAt(0) == "x") {
        E_selectedId = E_parameterValue.substring(1);
    } else  {
        E_selectedId = E_originalSelectedId;
    }

    // Store new selection data in control form
    E_setParameter(E_groupId, E_id);

    // Disable previously selected button.
    if (E_selectedId != null && E_selectedId != "" && E_id != E_selectedId) {
        document.images["E_TBIMG_" + E_selectedId].src = E_defaultImageUri;
    }

    // Enabled new selected button.
    if (E_id != null && E_id != "") {
        document.images["E_TBIMG_" + E_id].src = E_selectedImageUri;
    }

    // Notify server of change if necessary
    if (E_notify) {
        E_setAction(E_id, "press");
    }
}

function E_toggleRollover(E_id, E_stateId, E_imageUri, E_selectedImageUri, E_styleName) {
    if (E_imageUri != null) {
        var E_state = E_getParameter(E_stateId);
        if (E_state != null && E_state.length >= 2) {
            var E_stateString = E_state.substring(1);
            if (E_stateString == "1" || E_stateString == E_id) {
                E_imageSwap("E_TBIMG_" + E_id, E_selectedImageUri);
            } else {
                E_imageSwap("E_TBIMG_" + E_id, E_imageUri);
            }
        } else {
            E_imageSwap("E_TBIMG_" + E_id, E_imageUri);
        }
    }
    if (E_styleName != null) {
        E_applyStyleGroup("E_C_" + E_id, E_getStyle(E_styleName));
    }
}
