/* 
 * This file is part of the Echo Web Application Framework (hereinafter "Echo").
 * Copyright (C) 2002-2003 NextApp, Inc.
 *
 * Echo is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Echo is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Echo; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

var E_rootFrame = true;
var E_clientModel = null;
var E_notifyUnload = true;
var E_id = null;
var E_closePending = false;

/**
 * Closes this window.  If the window is the root window, notifies 
 * the client model to change the root window.
 */
function E_close() {
    E_notifyUnload = false;
    if (E_isRootWindow()) {
        E_clientModel.E_changeRootWindow();
    }
    window.close();
}

/**
 * Closes the window under the circumstance that it is the final window.
 * The client model does not need to be notified in this case.
 */
function E_closeFinalWindow() {
    E_notifyUnload = false;
    window.close();
}

/** 
 * Returns the client model for this window.
 */
function E_getClientModel() {
    return E_clientModel;
}

/**
 * Returns true if this window is the root window.
 */
function E_isRootWindow() {
    return window == E_clientModel.E_getRootWindow();
}

/**
 * Unregisters and closes all registered windows that have their
 * "closePending" flag set.
 */
function E_handleClosePendingWindows() {
    var E_windowIds = E_clientModel.E_getWindowIds();
    var E_length = E_windowIds.E_size();
    for (E_i = 0; E_i < E_length; ++E_i) {
        var E_windowId = E_windowIds.E_get(E_i);
        var E_window = E_clientModel.E_getWindow(E_windowId);
        if (E_window.E_closePending) {
            if (E_window.E_isRootWindow()) {
                alert("Error changing controller from closing window.");
            }
            if (E_clientModel) {
                E_clientModel.E_removeWindow(E_windowId);
                E_window.E_close();
            }
        }
    }
}

/**
 * Called when this window is unloaded (closed or reloaded).
 */
function E_handleUnload() {
    if (E_notifyUnload && E_clientModel && !E_clientModel.E_verify(false)) {
        if (E_isRootWindow()) {
            E_clientModel.E_changeRootWindow();
        } else {
            if (E_clientModel.E_getController().E_ready) {
                E_clientModel.E_getController().E_windowUnload();
            }
        }
    }
}

/**
 * Tests whether the windows opener has a clientModel.  
 * This method may throw permission exceptions if opener is not served
 * from same server for Cross-Site Scripting security reasons.
 */
function E_isOpenerAccessible() {
    if (window.opener && !window.opener.closed && window.opener.E_clientModel) {
        return true;
    } else {
        return false;
    }
}

/**
 * Called when this window is initialized so that it may establish
 * a connection to the ClientModel.
 */
function E_initClientModel(E_thisWindowId) {
    E_id = E_thisWindowId;
    if (E_try(null, "E_isOpenerAccessible")) { 
        E_clientModel = window.opener.E_clientModel;
        E_clientModel.E_addWindow(E_thisWindowId, window);
    } else {
        window.opener = null;
        E_clientModel = new E_ClientModel(E_thisWindowId);
    }
}

/**
 * Sets this window as the root window.
 * - Sets this window's window.opener to null.
 * - Sets all other window's window.opener property to this window.
 * - Creates new ClientModel and copies data from old one (A new
 *   ClientModel must be created because the old one may become
 *   invalid when it instantiating window is destroyed).
 *   Sets all other window's client model to newly created one.
 * - Closes windows that are "pending close" (as is the case when
 *   the window containing the old controller needs to be closed).
 * - Sends a synchronize event through the new Controller.
 */
function E_setAsRootWindow() {
    // Create new client model.
    var E_newClientModel = new E_ClientModel(E_id);
    var E_i;
    var E_windowIds = E_clientModel.E_getWindowIds();
    var E_length = E_windowIds.E_size();
    
    // The root window's opener should be null.
    window.opener = null;
    
    // Iterate through all open window ids.
    for (E_i = 0; E_i < E_length; ++E_i) {
        var E_windowId = E_windowIds.E_get(E_i);
        if (E_windowId != E_id) {
            // E_windowId is not this window.
            
            // Get the window.
            var E_window = E_clientModel.E_getWindow(E_windowId);
            
            // Add the window to the new client model's list of windows.
            E_newClientModel.E_addWindow(E_windowId, E_window);
            
            // Set the window's client model to the new client model.
            E_window.E_setClientModel(E_newClientModel);
            
            // Set the window's opener to this window.
            E_window.opener = window;
        }
    }
    
    // Set this window's client model to the new client model.
    E_setClientModel(E_newClientModel);
    
    // Close pending windows.
    E_handleClosePendingWindows();
    
    // Send synchronize event.
    E_clientModel.E_getController().E_synchronize();
}

/**
 * Sets this window's client model.  Used only by setAsRootwindow().
 */
function E_setClientModel(E_newValue) {
    E_clientModel = E_newValue;
}

/**
 * Shuts down the application, redirecting the root window to 
 * the specified URI.
 */
function E_shutdown(E_uri) {
    var E_windowIds = E_clientModel.E_getWindowIds();
    var E_windowId;
    var E_window;
    
    for (var E_i = 0; E_i < E_windowIds.E_size(); ++E_i) {
        E_windowId = E_windowIds.E_get(E_i);
        E_window = E_clientModel.E_getWindow(E_windowId);
        E_window.E_notifyUnload = false;
        if (E_windowId != E_id) {
            E_window.close();
        }
    }
    
    window.location = E_uri;
}
